BoardInfo class final

A collection of the motherboard.

Annotations
  • @JsonSerializable.new()

Constructors

BoardInfo({required String? manufacturer, required String? productName, required String? version})
Construct a motherboard information.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
manufacturer String?
A company who produce this motherboard.
final
productName String?
Name of motherboard.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
Motherboard version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return an unmodifiable Map to notate information of BoardInfo.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited