testing library
Provide a mock test framework that no real hardware information will be used during executing testes.
Classes
- MockDeviceVendorInfoLoader
- Another DeviceVendorInfoLoader that all data are defined already in MockDeviceVendorInfoLoader.new and MockDeviceVendorInfoLoader.simulateDelay.