hasHypervisor function
Determine this machine enabled hypervisor, no matter it running in guest OS, container or actually physical machine.
It possible return true if:
- Running inside of virtual machine or a container.
- Enables type 1 hypervisor service (e.g. Hyper-V, KVM) in host machine.
The result always return false if using MockDeviceVendorInfoLoader.
This result is not related with BIOS information that it does not appeared in exportRawVendorInfoToJson.
Implementation
Future<bool> hasHypervisor() => DeviceVendorInfo.instance.isVirtualPlatform;